==> ezpublish-4.0.0.tgz: ezpublish/extension/ezodf/translations/chi-TW/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>置換</translation>
    </message>
    <message>
        <source>Choose document placement</source>
        <translation>選擇文件位置</translation>
    </message>
    <message>
        <source>Upload file</source>
        <translation>上傳檔案</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>匯出物件</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>OpenOffice.org 匯入</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>OpenOffice.org 匯出</translation>
    </message>
    <message>
        <source>Export eZ publish content to OpenOffice.org</source>
        <translation>將 eZ publish 內容匯出到 OpenOffice.org</translation>
    </message>
    <message>
        <source>Here you can export any eZ publish content object to an OpenOffice.org Writer document format.</source>
        <translation>您可以在這裏將任何 eZ publish 的內容物件匯出為 OpenOffice.org Writer 的文件格式。</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>現在文件已匯入</translation>
    </message>
     <message>
        <source>The object was imported as: %class_name</source>
        <translation>將物件匯入為：%class_name</translation>
    </message>
     <message>
        <source>Document imported as</source>
        <translation>將文件匯入為</translation>
    </message>
     <message>
        <source>The images are placed in the media and can be re-used.</source>
        <translation>圖像放置於媒體庫中且能被再利用。</translation>
    </message>
     <message>
        <source>Import another document</source>
        <translation>匯入另一份文件</translation>
    </message>
     <message>
        <source>Import OpenOffice.org document</source>
        <translation>匯入 OpenOffice.org 文件</translation>
    </message>
     <message>
        <source>Replace document</source>
        <translation>置換文件</translation>
    </message>
     <message>
        <source>Import to</source>
        <translation>匯入到</translation>
    </message>
     <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ publish from this page. You are
asked where to place the document and eZ publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation>您可以經由此頁直接將 OpenOffice.org Writer 文件匯入 eZ publish。
您將被要求輸入放置文件的地方，eZ publish 則會完成剩下的工作。文件於匯入時會轉換為適當的類別，在匯入完成之後您會獲得相關說明。
圖像被放置於媒體庫中，因此您可以在其他文章中重覆利用它們。</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export OpenOffice.org</source>
        <translation>匯出 OpenOffice.org</translation>
    </message>
    <message>
        <source>Export PDF</source>
        <translation>匯出 PDF</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>匯出 Word</translation>
    </message>
    <message>
        <source>Import OpenOffice.org</source>
        <translation>匯入 OpenOffice.org</translation>
    </message>
    <message>
        <source>Replace OpenOffice.org</source>
        <translation>置換 OpenOffice.org</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>選擇文件位置</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>請選擇 OpenOffice.org 物件的位置
    選取位置之後按下 %buttonname 鈕。
    也可以使用最近開啟與書籤項目進行快速放置。
    按下位置名稱以變更瀏覽清單。</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>不支援目的檔案格式</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>PDF 轉換失敗</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Word 轉換失敗</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>無法擷取節點，或是沒有讀取權限</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>無法在伺服器端開啟檔案 %1</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>不允許擴充檔名或者型態。</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>無法解析 XML。</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>無法開啟通訊端。請檢查 extension/ezodf/daemon.php 是否正在運行。</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>無法轉換所給的文件。</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>無法呼叫守護程式。無法藉由衍生建立子程序。</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>守護程式回報錯誤。</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>不明的節點。</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>存取被拒。</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>匯入時發生錯誤。</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>在 odf.ini 中所指定的不明內容類別：</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>不明錯誤。</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>檔案類型：</translation>
    </message>
    <message>
        <source>Unable to fetch node with id  </source>
        <translation>無法以 id 擷取節點</translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>無法建立圖像資料夾，存取被拒。</translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation>不支援該文件。</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>無法匯入。找不到檔案。已經匯入了嗎？</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>無法匯入文件，所提供的位置 nodeID 無效。</translation>
    </message>
    <message>
        <source>Document is not suported.</source>
        <translation>不支援該文件。</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>無法儲存上傳的檔案，無法匯入。</translation>
    </message>
</context>
</TS>

==> ezpublish-4.1.3p3.tgz: ezpublish/extension/ezodf/translations/chi-TW/translation.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>extension/ezodf</name>
    <message>
        <source>Upload file</source>
        <translation>上傳檔案</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Export Object</source>
        <translation>匯出物件</translation>
    </message>
    <message>
        <source>OpenOffice.org import</source>
        <translation>OpenOffice.org 匯入</translation>
    </message>
    <message>
        <source>OpenOffice.org export</source>
        <translation>OpenOffice.org 匯出</translation>
    </message>
    <message>
        <source>Document is now imported</source>
        <translation>現在文件已匯入</translation>
    </message>
    <message>
        <source>The object was imported as: %class_name</source>
        <translation>將物件匯入為：%class_name</translation>
    </message>
    <message>
        <source>Document imported as</source>
        <translation>將文件匯入為</translation>
    </message>
    <message>
        <source>Import another document</source>
        <translation>匯入另一份文件</translation>
    </message>
    <message>
        <source>Import OpenOffice.org document</source>
        <translation>匯入 OpenOffice.org 文件</translation>
    </message>
    <message>
        <source>Replace document</source>
        <translation>置換文件</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation>匯入到</translation>
    </message>
    <message>
        <source>Export eZ Publish content to OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Here you can export any eZ Publish content object to an OpenOffice.org Writer document format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The images are placed in the media library and can be re-used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can import OpenOffice.org Writer documents directly into eZ Publish from this page. You are
asked where to place the document and eZ Publish does the rest. The document is converted into
the appropriate class during the import, you get a notice about this after the import is done.
Images are placed in the media library so you can re-use them in other articles.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/browse</name>
    <message>
        <source>Choose document placement</source>
        <translation>選擇文件位置</translation>
    </message>
    <message>
        <source>Please choose the placement for the OpenOffice.org object.

    Select the placements and click the %buttonname button.
    Using the recent and bookmark items for quick placement is also possible.
    Click on placement names to change the browse listing.</source>
        <translation>請選擇 OpenOffice.org 物件的位置
    選取位置之後按下 %buttonname 鈕。
    也可以使用最近開啟與書籤項目進行快速放置。
    按下位置名稱以變更瀏覽清單。</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/export/error</name>
    <message>
        <source>Destination file format not supported</source>
        <translation>不支援目的檔案格式</translation>
    </message>
    <message>
        <source>PDF conversion failed</source>
        <translation>PDF 轉換失敗</translation>
    </message>
    <message>
        <source>Word conversion failed</source>
        <translation>Word 轉換失敗</translation>
    </message>
    <message>
        <source>Unable to fetch node, or no read access</source>
        <translation>無法擷取節點，或是沒有讀取權限</translation>
    </message>
    <message>
        <source>Unable to open file %1 on server side</source>
        <translation>無法在伺服器端開啟檔案 %1</translation>
    </message>
</context>
<context>
    <name>extension/ezodf/import/error</name>
    <message>
        <source>File extension or type is not allowed.</source>
        <translation>不允許擴充檔名或者型態。</translation>
    </message>
    <message>
        <source>Could not parse XML.</source>
        <translation>無法解析 XML。</translation>
    </message>
    <message>
        <source>Can not open socket. Please check if extension/ezodf/daemon.php is running.</source>
        <translation>無法開啟通訊端。請檢查 extension/ezodf/daemon.php 是否正在運行。</translation>
    </message>
    <message>
        <source>Can not convert the given document.</source>
        <translation>無法轉換所給的文件。</translation>
    </message>
    <message>
        <source>Unable to call daemon. Fork can not create child process.</source>
        <translation>無法呼叫守護程式。無法藉由衍生建立子程序。</translation>
    </message>
    <message>
        <source>Daemon reported error.</source>
        <translation>守護程式回報錯誤。</translation>
    </message>
    <message>
        <source>Unknown node.</source>
        <translation>不明的節點。</translation>
    </message>
    <message>
        <source>Access denied.</source>
        <translation>存取被拒。</translation>
    </message>
    <message>
        <source>Error during import.</source>
        <translation>匯入時發生錯誤。</translation>
    </message>
    <message>
        <source>Unknown content class specified in odf.ini:</source>
        <translation>在 odf.ini 中所指定的不明內容類別：</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>不明錯誤。</translation>
    </message>
    <message>
        <source>Filetype: </source>
        <translation>檔案類型：</translation>
    </message>
    <message>
        <source>Folder for images could not be created, access denied.</source>
        <translation>無法建立圖像資料夾，存取被拒。</translation>
    </message>
    <message>
        <source>Cannot import. File not found. Already imported?</source>
        <translation>無法匯入。找不到檔案。已經匯入了嗎？</translation>
    </message>
    <message>
        <source>Cannot import document, supplied placement nodeID is not valid.</source>
        <translation>無法匯入文件，所提供的位置 nodeID 無效。</translation>
    </message>
    <message>
        <source>Cannot store uploaded file, cannot import.</source>
        <translation>無法儲存上傳的檔案，無法匯入。</translation>
    </message>
    <message>
        <source>Unable to fetch node with id </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension/ezodf/popupmenu</name>
    <message>
        <source>Export PDF</source>
        <translation>匯出 PDF</translation>
    </message>
    <message>
        <source>Export Word</source>
        <translation>匯出 Word</translation>
    </message>
    <message>
        <source>OpenOffice.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace OpenOffice</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
